Autenticação Mecânica / Ficha de Compensação Código de baixa Sacador / Avalista Sacado Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Stoq Retail Management - www.stoq.com.br Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento 06 R$ 10,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 400 N 30/05/2011 06/00000000400-6 Cedente Agência/Código cedente Moda Stoq 0278-0/0029232-4 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 30/05/2011 237-2 23790.27804 60000.000046 00002.923209 2 49830000001000 237-2 Recibo do Sacado Autenticação Mecânica Cedente Agência/Código Cedente Data Documento Vencimento Sacado Nosso Número N. do documento Valor Documento Demonstrativo Moda Stoq 0278-0/0029232-4 30/05/2011 30/05/2011 Client 06/00000000400-6 400 10,00 sale XXX XXX - description